import type { ErrorReporter, ErrorResolver } from '@lokalise/node-core';
import type { ZodSchema } from 'zod';
import type { Logger, TransactionObservabilityManager } from '../types/MessageQueueTypes';
export type QueueDependencies = {
    errorReporter: ErrorReporter;
    logger: Logger;
};
export type QueueConsumerDependencies = {
    consumerErrorResolver: ErrorResolver;
    transactionObservabilityManager: TransactionObservabilityManager;
};
export type QueueOptions<MessagePayloadType extends object, QueueConfiguration extends object> = {
    messageSchema: ZodSchema<MessagePayloadType>;
    messageTypeField: string;
    queueName: string;
    queueConfiguration: QueueConfiguration;
};
export declare abstract class AbstractQueueService<MessagePayloadType extends object, DependenciesType extends QueueDependencies, QueueConfiguration extends object, OptionsType extends QueueOptions<MessagePayloadType, QueueConfiguration> = QueueOptions<MessagePayloadType, QueueConfiguration>> {
    protected readonly queueName: string;
    protected readonly errorReporter: ErrorReporter;
    protected readonly messageSchema: ZodSchema<MessagePayloadType>;
    protected readonly logger: Logger;
    protected readonly messageTypeField: string;
    protected readonly queueConfiguration: QueueConfiguration;
    constructor({ errorReporter, logger }: DependenciesType, { messageSchema, messageTypeField, queueName, queueConfiguration }: OptionsType);
    protected handleError(err: unknown): void;
    abstract close(): Promise<unknown>;
}
